@@ -1,7 +1,7 @@
 /*
  * md5.h        Structures and prototypes for md5.
  *
- * Version:     $Id: md5.h,v 1.18 2007/11/23 13:46:55 aland Exp $
+ * Version:     $Id: md5.h,v 1.19 2008/06/05 11:48:25 aland Exp $
  * License:		LGPL, but largely derived from a public domain source.
  *
  */
@@ -10,7 +10,7 @@
 #define _FR_MD5_H
 
 #include <freeradius/ident.h>
-RCSIDH(md5_h, "$Id: md5.h,v 1.18 2007/11/23 13:46:55 aland Exp $")
+RCSIDH(md5_h, "$Id: md5.h,v 1.19 2008/06/05 11:48:25 aland Exp $")
 
 #ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
@@ -26,6 +26,7 @@ RCSIDH(md5_h, "$Id: md5.h,v 1.18 2007/11/23 13:46:55 aland Exp $")
 
 #include <string.h>
 
+#ifndef WITH_OPENSSL_MD5
 /*  The below was retrieved from
  *  http://www.openbsd.org/cgi-bin/cvsweb/~checkout~/src/sys/crypto/md5.h?rev=1.1
  *  With the following changes: uint64_t => uint32_t[2]
@@ -67,4 +68,15 @@ void	 fr_MD5Transform(uint32_t [4], const uint8_t [MD5_BLOCK_LENGTH])
 /*		__attribute__((__bounded__(__minbytes__,2,MD5_BLOCK_LENGTH)))*/;
 /* __END_DECLS */
 
+#else  /* WITH_OPENSSL_HASH */
+
+#include <openssl/md5.h>
+
+#define FR_MD5_CTX	MD5_CTX
+#define fr_MD5Init	MD5_Init
+#define fr_MD5Update	MD5_Update
+#define fr_MD5Final	MD5_Final
+#define fr_MD5Transform MD5_Transform
+#endif
+
 #endif /* _FR_MD5_H */
