@@ -5,12 +5,12 @@
  * missing.h	Replacements for functions that are or can be
  *		missing on some platforms.
  *
- * Version:	$Id: missing.h,v 1.41 2007/11/26 12:46:18 aland Exp $
+ * Version:	$Id: missing.h,v 1.42 2008/02/16 09:20:06 aland Exp $
  *
  */
 
 #include <freeradius/ident.h>
-RCSIDH(missing_h, "$Id: missing.h,v 1.41 2007/11/26 12:46:18 aland Exp $")
+RCSIDH(missing_h, "$Id: missing.h,v 1.42 2008/02/16 09:20:06 aland Exp $")
 
 #include <freeradius/autoconf.h>
 
@@ -391,4 +391,8 @@ int gettimeofday (struct timeval *tv, void *tz);
 #define F_TEST  _LK_RLCK  /* Test section for locks by other processes. */
 #endif
 
+#ifndef offsetof
+# define offsetof(TYPE, MEMBER) ((size_t) &((TYPE *)0)->MEMBER)
+#endif
+
 #endif /* _FR_MISSING_H */
