@@ -5,7 +5,7 @@
  * packet.h	Structures and prototypes
  *		for packet manipulation
  *
- * Version:	$Id: packet.h,v 1.5 2007/11/23 13:46:55 aland Exp $
+ * Version:	$Id: packet.h,v 1.6 2008/02/16 09:20:05 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  */
 
 #include <freeradius/ident.h>
-RCSIDH(packet_h, "$Id: packet.h,v 1.5 2007/11/23 13:46:55 aland Exp $")
+RCSIDH(packet_h, "$Id: packet.h,v 1.6 2008/02/16 09:20:05 aland Exp $")
 
 uint32_t fr_request_packet_hash(const RADIUS_PACKET *packet);
 uint32_t fr_reply_packet_hash(const RADIUS_PACKET *packet);
@@ -62,11 +62,6 @@ RADIUS_PACKET *fr_packet_list_recv(fr_packet_list_t *pl, fd_set *set);
 int fr_packet_list_num_incoming(fr_packet_list_t *pl);
 int fr_packet_list_num_outgoing(fr_packet_list_t *pl);
 
-
-#ifndef offsetof
-# define offsetof(TYPE, MEMBER) ((size_t) &((TYPE *)0)->MEMBER)
-#endif
-
 /*
  *	"find" returns a pointer to the RADIUS_PACKET* member in the
  *	caller's structure.  In order to get the pointer to the *top*
