@@ -1,7 +1,7 @@
 /*
  * radius.h	Constants of the radius protocol.
  *
- * Version:	$Id: radius.h,v 1.90 2007/11/28 12:32:10 aland Exp $
+ * Version:	$Id: radius.h,v 1.93 2008/04/25 06:20:55 aland Exp $
  *
  */
 
@@ -114,6 +114,7 @@
 #define PW_ARAP_CHALLENGE_RESPONSE	84
 #define PW_NAS_PORT_ID_STRING  		87
 #define PW_FRAMED_POOL			88
+#define PW_CHARGEABLE_USER_IDENTITY	89
 #define PW_NAS_IPV6_ADDRESS		95
 
 #define PW_EXTENDED_ATTRIBUTE		192
@@ -145,7 +146,7 @@
 #define PW_EAP_TLS_REQUIRE_CLIENT_CERT	1019
 #define PW_CLIENT_SHORTNAME		1024
 #define PW_LOAD_BALANCE_KEY		1025
-
+#define PW_RAW_ATTRIBUTE		1026
 #define PW_TNC_VLAN_ACCESS		1027
 #define PW_TNC_VLAN_ISOLATE		1028
 #define PW_USER_CATEGORY		1029
@@ -216,6 +217,8 @@
 #define PW_VIRTUAL_SERVER		1099
 #define PW_CLEARTEXT_PASSWORD		1100
 #define PW_PASSWORD_WITH_HEADER		1101
+#define PW_MODULE_RETURN_CODE		1108
+#define PW_PACKET_ORIGINAL_TIMESTAMP   	1109
 
 /*
  *	Integer Translations
